@@ -8,16 +8,16 @@ const bench = common.createBenchmark(main, {
   n: [4e5]
 });
 
-function main(conf) {
-  const n = +conf.n;
-  const method = conf.method;
-  const chunk = Buffer.alloc(+conf.inputLen, 'a');
+function main({ n, method, inputLen }) {
+  // Default method value for testing.
+  method = method || 'deflate';
+  const chunk = Buffer.alloc(inputLen, 'a');
 
-  var i = 0;
   switch (method) {
     // Performs `n` writes for a single deflate stream
-    case 'createDeflate':
-      var deflater = zlib.createDeflate();
+    case 'createDeflate': {
+      let i = 0;
+      const deflater = zlib.createDeflate();
       deflater.resume();
       deflater.on('finish', () => {
         bench.end(n);
@@ -30,9 +30,11 @@ function main(conf) {
         deflater.write(chunk, next);
       })();
       break;
+    }
     // Performs `n` single deflate operations
-    case 'deflate':
-      var deflate = zlib.deflate;
+    case 'deflate': {
+      let i = 0;
+      const deflate = zlib.deflate;
       bench.start();
       (function next(err, result) {
         if (i++ === n)
@@ -40,14 +42,16 @@ function main(conf) {
         deflate(chunk, next);
       })();
       break;
+    }
     // Performs `n` single deflateSync operations
-    case 'deflateSync':
-      var deflateSync = zlib.deflateSync;
+    case 'deflateSync': {
+      const deflateSync = zlib.deflateSync;
       bench.start();
-      for (; i < n; ++i)
+      for (let i = 0; i < n; ++i)
         deflateSync(chunk);
       bench.end(n);
       break;
+    }
     default:
       throw new Error('Unsupported deflate method');
   }
