@@ -21,6 +21,8 @@
 
 'use strict';
 const common = require('../common');
+if (common.isIBMi)
+  common.skip('IBMi does not support fs.watch()');
 
 const assert = require('assert');
 const fs = require('fs');
